Package: clordr
Type: Package
Title: Composite Likelihood Inference and Diagnostics for Replicated
        Spatial Ordinal Data
Version: 1.7.2
Authors@R: c(person("Ting Fung", "Ma", email = "tingfung@mailbox.sc.edu", role = c("cre", "aut")),
    person("Pingping", "Wang", email = "catherinewpp@126.com", role = "aut"),
    person("Jun", "Zhu", email = "jzhu@stat.wisc.edu", role = "aut"),
    person("Dipankar", "Bandyopadhyay", email = "bandyopd@gmail.com", role = "ctb"),
    person("Yincai", "Tang", email = "yctang@stat.ecnu.edu.cn", role= "ctb"))
Maintainer: Ting Fung Ma <tingfung@mailbox.sc.edu>
Description: Composite likelihood parameter estimate and asymptotic covariance matrix are calculated for the spatial ordinal data with replications, where spatial ordinal response with covariate and both spatial exponential covariance within subject and independent and identically distributed measurement error.  Parameter estimation can be performed by either solving the gradient function or maximizing composite log-likelihood. Parametric bootstrapping is used to estimate the Godambe information matrix and hence the asymptotic standard error and covariance matrix with parallel processing option. Moreover, the proposed surrogate residual, which extends the results of Liu and Zhang (2017) <doi: 10.1080/01621459.2017.1292915>, can act as a useful tool for model diagnostics.
License: GPL-2
Imports: pbivnorm (>= 0.6.0), MASS (>= 7.3-45), rootSolve (>= 1.7),
        parallel, doParallel (>= 1.0.11), foreach (>= 1.2.0),
        tmvmixnorm (>= 1.0.2), utils, stats
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-08 17:02:47 UTC; ralph
Repository: CRAN
Date/Publication: 2026-05-09 16:30:18 UTC
Author: Ting Fung Ma [cre, aut],
  Pingping Wang [aut],
  Jun Zhu [aut],
  Dipankar Bandyopadhyay [ctb],
  Yincai Tang [ctb]
Built: R 4.6.0; ; 2026-05-09 17:44:07 UTC; unix
