# Generated by roxygen2: do not edit by hand

export(cl)
export(cl.rord)
export(cl_l)
export(cle.rord)
export(clic)
export(sim.rord)
export(surrogate.residual)
import(MASS)
import(doParallel)
import(foreach)
import(parallel)
import(pbivnorm)
import(rootSolve)
import(stats)
import(tmvmixnorm)
import(utils)
